==> hyades.ies.sdk.3.0.0_20040331_1118.zip: org/eclipse/hyades/test/ui/internal/util/TestUIUtil.java <==
/*******************************************************************************
 * Copyright (c) 2003 Hyades project.
 * All rights reserved. This program and the accompanying materials 
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
package org.eclipse.hyades.test.ui.internal.util;

import java.util.Iterator;
import java.util.List;

import org.eclipse.hyades.models.common.common.CMNNamedElement;
import org.eclipse.hyades.test.ui.TestUIPlugin;

/**
 * @author marcelop
 * @since 0.3.0
 */
public class TestUIUtil
{
	/**
	 * Returns a unique name based on the specified base and list of CMNNamedElement.
	 * @param baseName
	 * @param namedElementList
	 * @return String
	 */
	public static String getUniqueName(String baseName, List namedElementList)
	{
		int id = namedElementList.size()+1;
		String[] args = new String[]{baseName, Integer.toString(id)};
		String name = TestUIPlugin.getString("NME_CONCAT", args);

		for (Iterator i = namedElementList.iterator(); i.hasNext();)
		{
			CMNNamedElement namedElement = (CMNNamedElement)i.next();
			if(name.equals(namedElement.getName()))
			{
				args[1] = Integer.toString(++id);
				name = TestUIPlugin.getString("NME_CONCAT", args);
				i = namedElementList.iterator();
			}
		}
		
		return name;
	}
}

==> hyades.ies.sdk.3.0.1.1_20041012_1600.zip: org/eclipse/hyades/test/ui/internal/util/TestUIUtil.java <==
/*******************************************************************************
 * Copyright (c) 2003 Hyades project.
 * All rights reserved. This program and the accompanying materials 
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
package org.eclipse.hyades.test.ui.internal.util;

import java.util.Iterator;
import java.util.List;

import org.eclipse.hyades.models.common.common.CMNNamedElement;
import org.eclipse.hyades.test.ui.TestUIPlugin;

/**
 * @author marcelop
 * @since 0.3.0
 * @deprecated use {@link org.eclipse.hyades.test.ui.util.TestUIUtil} instead.
 */
public class TestUIUtil
{
	/**
	 * Returns a unique name based on the specified base and list of CMNNamedElement.
	 * @param baseName
	 * @param namedElementList
	 * @return String
	 */
	public static String getUniqueName(String baseName, List namedElementList)
	{
		int id = namedElementList.size()+1;
		String[] args = new String[]{baseName, Integer.toString(id)};
		String name = TestUIPlugin.getString("NME_CONCAT", args); //$NON-NLS-1$

		for (Iterator i = namedElementList.iterator(); i.hasNext();)
		{
			CMNNamedElement namedElement = (CMNNamedElement)i.next();
			if(name.equals(namedElement.getName()))
			{
				args[1] = Integer.toString(++id);
				name = TestUIPlugin.getString("NME_CONCAT", args); //$NON-NLS-1$
				i = namedElementList.iterator();
			}
		}
		
		return name;
	}
}
